@@ -1,5 +1,5 @@
 /**************************************************************************
-*   Copyright (C) 2005-2015 by Oleksandr Shneyder                         *
+*   Copyright (C) 2005-2016 by Oleksandr Shneyder                         *
 *   o.shneyder@phoca-gmbh.de                                              *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
@@ -27,7 +27,7 @@ CUPSPrinterSettingsDialog::CUPSPrinterSettingsDialog (
     QString prnName,
     CUPSPrint*  cupsObject,
     QWidget * parent,
-    Qt::WFlags flags
+    Qt::WindowFlags flags
 ) :QDialog ( parent, flags )
 {
 	m_cups=cupsObject;
