@@ -337,6 +337,14 @@ public:
         ESD
     };
 
+    enum key_types {
+        RSA_KEY_TYPE,
+        DSA_KEY_TYPE,
+        ECDSA_KEY_TYPE,
+        ED25519_KEY_TYPE,
+        UNKNOWN_KEY_TYPE
+    };
+
     static bool debugging;
 
     static bool portable;
@@ -605,6 +613,7 @@ private:
     bool defaultXinerama;
     bool cardStarted;
     bool defaultSetKbd;
+    bool autoresume;
     bool showExport;
     bool usePGPCard;
     bool miniMode;
@@ -634,6 +643,9 @@ private:
     QString sshPort;
     QString clientSshPort;
     QString defaultSshPort;
+#ifdef Q_OS_WIN
+    QString sshLog;
+#endif
     QVBoxLayout* selectSesDlgLayout;
     SshMasterConnection* sshConnection;
     QList<SshMasterConnection*> serverSshConnections;
@@ -1033,6 +1045,7 @@ private slots:
     void slotSshConnectionError ( QString message, QString lastSessionError );
     void slotSshServerAuthError ( int error, QString sshMessage, SshMasterConnection* connection );
     void slotSshServerAuthPassphrase ( SshMasterConnection* connection, bool verificationCode );
+    void slotSshServerAuthChallengeResponse( SshMasterConnection* connection, QString Challenge );
     void slotSshUserAuthError ( QString error );
     void slotSshConnectionOk();
     void slotServSshConnectionOk(QString server);
@@ -1192,7 +1205,7 @@ private:
 #endif
     void filterDesktops ( const QString& filter,
                           bool strict=false );
-    void generateHostDsaKey();
+    void generateHostKey(key_types key_type);
     void generateEtcFiles();
     QString u3DataPath();
     void cleanPortable();
